@@ -2,8 +2,9 @@ context("async requests")
 
 test_that("It's possible to do async queries",{
   skip_on_cran()
-  meas <- aq_measurements(city = "Delhi",
+  skip_if_offline()
+  meas <- aq_measurements(city = "Escaldes-Engordany",
                           date_from = as.character(Sys.Date() - 1),
-                          limit = 100)
+                          limit = 10)
   expect_that(meas, is_a("tbl_df"))
 })
